==> nono-0.7.0.tar.gz: nono-0.7.0/vm/mpu.h <==
//
// nono
// Copyright (C) 2020 nono project
// Licensed under nono-license.txt
//

//
// メイン MPU (680x0/88xx0) 共通部
//

#pragma once

#include "device.h"
#include "event.h"
#include "message.h"

class Debugger;
class MainbusDevice;
class Syncer;

class MPUDevice : public Device
{
	using inherited = Device;
 public:
	MPUDevice();
	~MPUDevice() override;

	bool Init() override;
	void PowerOff() override;

	// 現在実行中の命令の PC を取得
	virtual uint32 GetPPC() const = 0;

	// 現在の VBR を取得
	virtual uint32 GetVBR() const = 0;

	// 現在アクセス中の論理アドレス、物理アドレスを取得。
	// Laddr == Paddr が MMU オフなのか PA=VA で運用中なのかの区別は
	// ここでは付かない。
	virtual uint32 GetLaddr() const = 0;
	virtual uint32 GetPaddr() const = 0;

	// MPU 名を取得する。("MC68030" みたいなやつ、ログ名とは別)
	virtual const char *GetMPUName() const = 0;

	// MPU クロック [kHz] を取得する。
	int GetClockSpeed() const { return clock_khz; }

	// MPU クロック [nsec] を取得する。
	uint64 GetClock_nsec() const { return clock_nsec; }

	// 割り込み発生を MPU に通知
	virtual void Interrupt(int level) = 0;

	// デバイスが CI (キャッシュ禁止) をセットする。
	virtual void SetCI() = 0;

 protected:
	void TraceMessage(MessageID, uint32);
	virtual void SetTrace(bool trace_on) = 0;

	int clock_khz {};		// MPU クロック [kHz]
	uint64 clock_nsec {};	// MPU クロック [nsec]

	bool resetting {};		// リセット処理中フラグ

	Debugger *debugger {};
	MainbusDevice *mainbus {};
	Syncer *syncer {};

	// 1命令実行イベント
	Event exec_event { this };

	// Round Mode (モニタ表示用)
	static const char * const rmstr[4];
};

static inline MPUDevice *GetMPUDevice() {
	return Object::GetObject<MPUDevice>(OBJ_MPU);
}

==> nono-0.7.2.tar.gz: nono-0.7.2/vm/mpu.h <==
//
// nono
// Copyright (C) 2020 nono project
// Licensed under nono-license.txt
//

//
// MPU 共通部
//

#pragma once

#include "device.h"
#include "event.h"
#include "message.h"

class Debugger;
class MainbusDevice;
class Syncer;

// 全 MPU の共通部
class MPUDevice : public Device
{
	using inherited = Device;
 public:
	MPUDevice(int objid_);
	~MPUDevice() override;

	bool Init() override;
	void PowerOff() override;

	// 現在実行中の命令の PC を取得
	virtual uint32 GetPPC() const = 0;

 protected:
	// 1命令実行イベント
	Event exec_event { this };

	Debugger *debugger {};
};

// メイン MPU (680x0/88xxx0) 共通部
class MainMPUDevice : public MPUDevice
{
	using inherited = MPUDevice;
 public:
	MainMPUDevice();
	~MainMPUDevice() override;

	bool Init() override;

	// 現在の VBR を取得
	virtual uint32 GetVBR() const = 0;

	// 現在アクセス中の論理アドレス、物理アドレスを取得。
	// Laddr == Paddr が MMU オフなのか PA=VA で運用中なのかの区別は
	// ここでは付かない。
	virtual uint32 GetLaddr() const = 0;
	virtual uint32 GetPaddr() const = 0;

	// MPU 名を取得する。("MC68030" みたいなやつ、ログ名とは別)
	virtual const char *GetMPUName() const = 0;

	// MPU クロック [kHz] を取得する。
	int GetClockSpeed() const { return clock_khz; }

	// MPU クロック [nsec] を取得する。
	uint64 GetClock_nsec() const { return clock_nsec; }

	// 割り込み発生を MPU に通知
	virtual void Interrupt(int level) = 0;

	// デバイスが CI (キャッシュ禁止) をセットする。
	virtual void SetCI() = 0;

 protected:
	void TraceMessage(MessageID, uint32);
	virtual void SetTrace(bool trace_on) = 0;

	int clock_khz {};		// MPU クロック [kHz]
	uint64 clock_nsec {};	// MPU クロック [nsec]

	bool resetting {};		// リセット処理中フラグ

	MainbusDevice *mainbus {};
	Syncer *syncer {};

	// Round Mode (モニタ表示用)
	static const char * const rmstr[4];
};

static inline MainMPUDevice *GetMPUDevice() {
	return Object::GetObject<MainMPUDevice>(OBJ_MPU);
}
